.. Setup build dependency
.. include:: ../mons/spec.py
   :end-line: 0

Glossary
========

.. only:: man

   Name
   ----

   mons-glossary \- A Glossary of terms used in mons

   Synopsis
   --------

   \*

   Description
   -----------


.. glossarygen::

   .. py:currentmodule:: mons.spec
   .. automodule:: mons.spec
      :members:

See Also
--------
:manpage:`gitglossary(7)`
